Documentation
¶
Overview ¶
Package controller provides the business logic for the application
Index ¶
- func FindModulesInProjects(projects []model.Project) (result []model.Module, err error)
- func GetProjects(sortBy string) (result []model.Project, err error)
- func GetReleases(url string) (result []model.Release, err error)
- func ParseGithubURL(repo string) (owner string, name string, err error)
- func PrintModulesJSON(modules []model.Module)
- func PrintModulesTable(modules []model.Module)
- func PrintProjectsJSON(projects []model.Project)
- func PrintProjectsTable(projects []model.Project)
- func PrintReleasesJSON(releases []model.Release)
- func PrintReleasesTable(projects []model.Release)
- type ByForks
- type ByLastCommit
- type ByStars
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindModulesInProjects ¶
FindModulesInProjects fetches modules from Github repositories
func GetProjects ¶
GetProjects fetches projects from Github using the Search API
func GetReleases ¶
GetReleases fetches releases from a Github repository
func ParseGithubURL ¶
ParseGithubURL parses a GitHub repository URL and returns the owner and repository name.
func PrintModulesJSON ¶
PrintModulesJSON prints Modules in JSON format
func PrintModulesTable ¶
PrintModulesTable prints modules in table format
func PrintProjectsJSON ¶
PrintProjectsJSON prints Projects in JSON format
func PrintProjectsTable ¶
PrintProjectsTable prints Projects in Table format
func PrintReleasesJSON ¶
PrintReleasesJSON prints Releases in JSON format
func PrintReleasesTable ¶
PrintReleasesTable prints Releases in Table format
Types ¶
type ByForks ¶
ByForks sorts projects by their forks
type ByLastCommit ¶
ByLastCommit sorts projects by their last commit date
func (ByLastCommit) Len ¶
func (a ByLastCommit) Len() int
Implements the sort.Interface for []Project based on Last Commit
func (ByLastCommit) Less ¶
func (a ByLastCommit) Less(i, j int) bool
func (ByLastCommit) Swap ¶
func (a ByLastCommit) Swap(i, j int)